@@ -2,6 +2,7 @@
 #define ParserBase_h_included
 
 #include <vector>
+#include <iostream>
 
 
 namespace // anonymous
@@ -29,7 +30,7 @@ class ParserBase
     private:
         int d_stackIdx;
         std::vector<size_t>   d_stateStack;
-        std::vector<STYPE>      d_valueStack;
+        std::vector<STYPE>    d_valueStack;
 
     protected:
         enum Return
@@ -56,23 +57,25 @@ class ParserBase
         void ACCEPT() const throw(Return);
         void ERROR() const throw(ErrorRecovery);
         void clearin();
-
-        bool debug() const
-        {
-            return d_debug;
-        }
+        bool debug() const;
         void pop(size_t count = 1);
         void push(size_t nextState);
-        size_t reduce(PI const &productionInfo);
-        void setDebug(bool mode)
-        {
-            d_debug = mode;
-        }
+        void reduce(PI const &productionInfo);
         size_t top() const;
 
-// class ParserBase ends
-};
+    public:
+        void setDebug(bool mode);
+}; 
 
+inline bool ParserBase::debug() const
+{
+    return d_debug;
+}
+
+inline void ParserBase::setDebug(bool mode)
+{
+    d_debug = mode;
+}
 
 // As a convenience, when including ParserBase.h its symbols are available as
 // symbols in the class Parser, too.
