@@ -42,6 +42,8 @@ class Rules
     static Symbol *s_startSymbol;
 
     public:
+        Rules();
+
         static void setExpectedConflicts(size_t value);
         static Terminal const *eofTerminal();
         static Terminal const *errorTerminal();
@@ -91,6 +93,8 @@ class Rules
         void determineFirst();
         void determineFollow();
 
+        bool hasRules() const;
+
                 // associate an action with the currently defined rule
                 // production 
         void setAction(Block const &block);
@@ -101,6 +105,10 @@ class Rules
 
         void setLastPrecedence(size_t value);
 
+        void updatePrecedences();       // try to assign a precedence to 
+                                        // productions that don't yet have a
+                                        // precedence associated to them
+
         void setPrecedence(Terminal const *terminal);
                 // Set the explicit precedence of the currently defined
                 // production to the precedence of the given terminal.
@@ -138,9 +146,17 @@ class Rules
 
         void addFollowToFollow();
         static void expandFollow(Production *production);
+        static void updatePrecedence(Production *production, 
+                                     Terminal::Vector const &tv);
 };
 
 
+inline Rules::Rules()
+:
+    d_currentRule(0),
+    d_currentProduction(0)
+{}
+
 inline void Rules::setExpectedConflicts(size_t value)
 {
     s_nExpectedConflicts = value;
@@ -187,6 +203,11 @@ inline size_t Rules::nProductions() const
     return d_currentRule->nProductions();
 }
 
+inline bool Rules::hasRules() const
+{
+    return d_currentRule;
+}
+
 inline size_t Rules::nElements() const
 {
     return d_currentProduction->size();
