@@ -5,7 +5,7 @@ void SRConflict::removeReductions(StateItem::Vector &itemVector)
     for_each
     (
         d_rmReduction.begin(), d_rmReduction.end(),
-        Wrap1c<RmReduction, StateItem::Vector>(
+        FnWrap1c<RmReduction const &, StateItem::Vector &>(
                                     StateItem::removeReduction, itemVector)
     );
 }
